@@ -12,6 +12,19 @@ test_that("divisorsSieve generates correct numbers", {
                                                    25,40,50,100,125,
                                                    200,250,500,1000))
     
+    expect_equal(divisorsSieve(100L), 
+                 lapply(1:100, function(x) (1:x)[x %% (1:x) == 0]))
+    
+    ## lower bound less than sqrt(100) and greater than 1
+    expect_equal(divisorsSieve(100L, 5), 
+                 lapply(5:100, function(x) (1:x)[x %% (1:x) == 0]))
+    
+    expect_true(divisorsSieve(1, namedList = TRUE)==1)
+    expect_true(divisorsSieve(1, 1, TRUE)==1)
+    
+    expect_equal(divisorsSieve(1000000L, 1000005L), 
+                 lapply(1000000:1000005, function(x) (1:x)[x %% (1:x) == 0]))
+    
     ## Test Names
     expect_equal(as.integer(names(divisorsSieve(100, namedList = TRUE))), 1:100)
     expect_equal(as.numeric(names(divisorsSieve(10^12, 10^12 + 100,
